1.0.0 API documentation: Experimental extensions

| 1.0.0 API documentation

Modules
Experimental extensions

Experimental features not specified by GLSL specification. More...

## Modules
| GLM_GTX_associated_min_max
| Min and max functions that return associated values not the compared ones.
| GLM_GTX_bit
| GLM_GTX_closest_point
| GLM_GTX_color_encoding
| Allow to perform bit operations on integer values.
| GLM_GTX_color_space
| GLM_GTX_color_space_YCoCg
| GLM_GTX_common
| Provide functions to increase the compatibility with Cg and HLSL languages.
| GLM_GTX_compatibility
| GLM_GTX_component_wise
| GLM_GTX_dual_quaternion
| GLM_GTX_easing
| GLM_GTX_euler_angles
| GLM_GTX_extend
| GLM_GTX_extended_min_max
| GLM_GTX_exterior_product
| Allow to perform bit operations on integer values.
| GLM_GTX_fast_exponential
| GLM_GTX_fast_square_root
| GLM_GTX_fast_trigonometry
| GLM_GTX_functions
| GLM_GTX_gradient_paint
| GLM_GTX_handed_coordinate_space
| GLM_GTX_hash
| GLM_GTX_integer
| GLM_GTX_intersect
| GLM_GTX_io
| GLM_GTX_log_base
| GLM_GTX_matrix_cross_product
| GLM_GTX_matrix_decompose
| GLM_GTX_matrix_factorisation
| GLM_GTX_matrix_interpolation
| GLM_GTX_matrix_major_storage
| GLM_GTX_matrix_operation
| GLM_GTX_matrix_query
| GLM_GTX_matrix_transform_2d
| GLM_GTX_mixed_producte
| GLM_GTX_norm
| GLM_GTX_normal
| GLM_GTX_normalize_dot
| GLM_GTX_number_precision
| GLM_GTX_optimum_pow
| GLM_GTX_orthonormalize
| GLM_GTX_pca
| GLM_GTX_perpendicular
| GLM_GTX_polar_coordinates
| GLM_GTX_projection
| GLM_GTX_quaternion
| GLM_GTX_range
| GLM_GTX_raw_data
| GLM_GTX_rotate_normalized_axis
| GLM_GTX_rotate_vector
| GLM_GTX_scalar_multiplication
| GLM_GTX_scalar_relational
| GLM_GTX_spline
| GLM_GTX_std_based_type
| GLM_GTX_string_cast
| GLM_GTX_texture
| GLM_GTX_transform
| GLM_GTX_transform2
| GLM_GTX_type_aligned
| GLM_GTX_type_trait
| GLM_GTX_vec_swizzle
| GLM_GTX_vector_angle
| GLM_GTX_vector_query
| GLM_GTX_wrap

## Detailed Description

Experimental features not specified by GLSL specification.

Experimental extensions are useful functions and types, but the development of their API and functionality is not necessarily stable. They can change substantially between versions. Backwards compatibility is not much of an issue for them.

Even if it's highly unrecommended, it's possible to include all the extensions at once by including <glm/ext.hpp>. Otherwise, each extension needs to be included a specific file.